{% extends "admin/change_list.html" %}
{% load i18n %}
    
{% block object-tools %}
    {% if has_add_permission %}
        <ul class="object-tools">
            <li><a href="/admin/order/{{ cl.opts.object_name.lower}}orderitem/" class="historylink">Order</a></li>
            <li>
                <a href="add/{% if is_popup %}?_popup=1{% endif %}" class="addlink">
                    {% blocktrans with cl.opts.verbose_name as name %}Add {{ name }}{% endblocktrans %}
                </a>
            </li>
        </ul>
    {% endif %}
{% endblock %}
